# DepthAI-GUI

**This repository is a fork of PyFlow tool, to learn more about it, please [click here to go to the original repository](https://github.com/wonderworks-software/PyFlow)**

## Install 

```
pip install depthai-gui
```

## Usage

To start the GUI, run

```
depthai-gui
```

To run a specific example (`example.pygraph`) run

```
depthai-gui -f /path/to/example.pygraph
```
